#
# spec file for package yast2-sap-ha
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-sap-ha
Version:        4.5.11
Release:        150500.3.10.1
BuildArch:      noarch
Source0:        %{name}-%{version}.tar.bz2
Source1:        yast2-sap-ha-rpmlintrc

Requires:       conntrack-tools
Requires:       corosync
Requires:       corosync-qdevice
Requires:       crmsh
Requires:       csync2
Requires:       hawk2
Requires:       pacemaker
Requires:       yast2
Requires:       yast2-cluster >= 4.4.4
Requires:       yast2-ntp-client
Requires:       yast2-ruby-bindings
# for opening URLs
Requires:       xdg-utils
# for handling the SSH client
Requires:       expect
Requires:       firewalld
Requires:       openssh
%ifarch x86_64 ppc64le
Requires:       HANA-Firewall >= 2.0.3
%endif
Requires:       SAPHanaSR
Requires:       kmod
Requires:       util-linux
# for pidof
Requires:       sysvinit-tools

BuildRequires:  csync2
BuildRequires:  firewalld
BuildRequires:  kmod
BuildRequires:  sysvinit-tools
BuildRequires:  update-desktop-files
BuildRequires:  util-linux
BuildRequires:  yast2
BuildRequires:  yast2-cluster
BuildRequires:  yast2-devtools
BuildRequires:  yast2-ntp-client
BuildRequires:  yast2-packager
BuildRequires:  yast2-ruby-bindings
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake)
Summary:        SUSE High Availability Setup for SAP Products
License:        GPL-2.0-only
Group:          System/YaST
URL:            http://www.suse.com

%description
A YaST2 module to enable high availability for SAP HANA installations.

%prep
%setup -n %{name}-%{version}

%check
rake test:unit

%build

%install
mkdir -p %{buildroot}%{yast_vardir}/sap_ha/

rake install DESTDIR="%{buildroot}"

%post

%files
%defattr(-,root,root)
%doc %yast_docdir
%yast_desktopdir
%yast_clientdir
%yast_libdir
%{yast_dir}/data/sap_ha/
%{yast_vardir}/sap_ha/
%{yast_scrconfdir}/*.scr
%{yast_ybindir}

%changelog
* Fri Mar 15 2024 varkoly@suse.com
- yast2-sap-ha: Error occurred during the unattended installation: undefined class/module SapHA::Configuration::ClusterFinalizer
  (bsc#1221049)
- 4.5.11
* Wed Nov 29 2023 varkoly@suse.com
- yast2-sap-ha setup workflow is bad (bsc#1217596)
  Reworking the workflow:
  1. Setting up SAP HANA System Replication
  2. Setting up SAP HANA HA/DR providers
  3. Confiugring the base cluster on all nodes
  4. Configuring cluster properties and resources with the new function HANA.finalize
  The whole class ClusterFinlizer was removed.
- 4.5.10
* Thu Nov  9 2023 varkoly@suse.com
- yast2-sap-ha wizard terminates abruptly when save configuration option
  is selected post configuration (bsc#1214603)
- yast2-sap-ha does not set global_allocation_limit for non productive database
  (bsc#1216651)
- Take care that the read values from the saved configuration will
  not be overridden during initialization of the modules
- Check if the required HANA systems are installed on the nodes.
- 4.5.9
* Mon Aug  7 2023 varkoly@suse.com
- Set default value for global_alloc_limit to "0"
- Fix evaluation CustOpt settings. (bsc#1209204)
- Remove superfluously BuildRequires: HANA-Firewall
- 4.5.8
* Fri May 26 2023 varkoly@suse.com
- yast2-sap-ha for Cost-Opt scenario is not up-to-date with SR takeover in best practice guide (bsc#1209204)
- yast2-sap-ha can not configure firewall (bsc#1211027)
- Rework package sturcture to use the yast2 defaults
- New function to get the primary hostname on the master.
- Fix setting secondary and primary hostname for the template
- Do not enbale and start csync2 by installing the package. This is unsecure.
- The hook creation is deprecated. This was removed from wizard and from backend.
  This functionality now will be provided by the susCostOpt.py delivered by SAPHanaSR
  Now a key sus_<SID>_costopt must be created.
- 4.5.7
* Thu Feb 23 2023 varkoly@suse.com
- L3: yast2-sap-ha error - Could not adjust global.ini for the production system
  (bsc#1207740)
- Add csync2 to buildrequires
- 4.5.6
* Thu Dec 29 2022 varkoly@suse.com
- Clean up Rakefile
- Use ruby base64 to replace uuencode/uudecode
  (bsc#1206601)
- yast2-sap-ha: csync2 configuration not enabled (bsc#1202112)
  Enable csync2 by installing the package. yast2-sap-ha will
  not be executed on the second node.
- 4.5.5
* Fri Sep  9 2022 varkoly@suse.com
- YaST2 HA Setup for SAP Products - cannot input several instance numbers
  (bsc#1202979)
- 4.5.4
* Thu Sep  8 2022 mfilka@suse.com
- bsc#1203227
  - replaced fgrep by grep -F
- 4.5.3
* Tue Aug  9 2022 varkoly@suse.com
- yast2-sap-ha: csync2 configuration not enabled (bsc#1202112)
- 4.5.2
* Mon Jun 13 2022 varkoly@suse.com
- YaST2 sap_ha tool does not allow digits at the beginning of site names
  (bsc#1200427)
- 4.5.1
* Tue Jun  7 2022 varkoly@suse.com
- ruby-xmlrpc is not part of stdlib anymore
  Update requirement
- Adapt version to normal yast2 version
- 4.5.0
* Sun May 22 2022 varkoly@suse.com
- Introduce a new function refresh_all_proposals.
  This reads the proposal for the modules watchdog and fence.
  This is neccessary when reading an earlier configuration.
- Use .gsub instead of File.basename to find all modules files.
  Replace tab with spaces.
  (bsc#1197290)
- 1.0.14
* Fri May 13 2022 varkoly@suse.com
- system/watchdog.rb searches watchdog modules with .ko extension
  but we ship .ko.xz  (bsc#1197290)
- 1.0.13
* Tue May  3 2022 varkoly@suse.com
- Adapt ntp tests
- (bsc#1199029)
  softdog missing in Yast while configuring HA for SAP Products
- 1.0.12
* Tue Dec  7 2021 varkoly@suse.com
- kmod-compat has broken dependencies (bsc#1186618)
- 1.0.11
* Tue Oct 12 2021 varkoly@suse.com
- "SUSE SAP HA Yast wizard for HANA doesn´t configure the HANA hooks.
  (bsc#1190774)
  Add SAPHanaSR via global.ini as proposed in
  https://documentation.suse.com/sbp/all/html/SLES4SAP-hana-sr-guide-PerfOpt-15/index.html#id-1.10.6.6"
- Remove HANA takeover hook script. This is not necessary for HANA 2 any more.
- 1.0.10
* Wed Dec 11 2019 varkoly@suse.com
- bsc#1158843 hana-*: Broken gettext support
- 1.0.9
* Mon Oct 21 2019 varkoly@suse.com
- Fix breakage caused by systemd service library reorganization
  (bsc#1146220) - L3: Yast2 > HA Setup for SAP Products Crashes with
  "cannot import namespace 'SystemdService'"
  Apply proposed changes.
- 1.0.8
* Thu Sep 19 2019 varkoly@suse.com
- Fix breakage caused by systemd service library reorganization
  (bsc#1146220) - L3: Yast2 > HA Setup for SAP Products Crashes with
  "cannot import namespace 'SystemdService'"
- 1.0.7
* Tue Dec 18 2018 abelarbi@suse.de
- Version bump to 1.0.6
- Fix bug (bsc#1117765)
* Wed Oct 10 2018 kgronlund@suse.com
- Lower stickiness of IP group to match non-Azure configuration
- Log network timeout accessing Azure metadata
- Use crm configure load to replace the cluster configuration (#43)
* Fri Sep 28 2018 dakechi@suse.com
- Version bump to 1.0.5;
- Enhanced the module to be used on Azure with unattended mode
  support (fate#324542, fate#325956).
    + Supports the SBD fencing based options documented on the
    Azure best practices guide.
* Mon Aug 20 2018 lkrause@suse.com
- Version bump to 1.0.4;
- Bugfixing (fate#325957):
  - Fix the rpc server error when Y2DIR variable is set
  - Fix the copy_ssfs_keys method to not fail when no password is
    informed but there is passwordless ssh access between the nodes
* Fri Jul 27 2018 dakechi@suse.com
- Version bump to 1.0.3;
- Enhanced the module to be used in hands-free WF on Bare Metal
  (fate#325957):
    + included the parameter "readconfig" to read config files exported
    on the summary screen. Usage:
    yast2 sap_ha readconfig <config file path>
    + included the option "unattended" to start the configuration
    automatically based on the config file provided. Usage:
    yast2 sap_ha readconfig <config file path> unattended
* Fri Mar  9 2018 imanyugin@suse.com
- Version bump to 1.0.2;
- Adapt module for SLE-15 (bsc#1084712):
    + firewalld rules are generated by yast2-cluster via Y2Firewall.
    The user must enable the cluster service manually.
    + it is left for the user to make sure that port 8080 is open for
    the RPC Server on the secondary node in order to provision it
* Tue Feb 13 2018 imanyugin@suse.com
- Package: adjust dependencies for SLE-15 (bsc#1079235):
    + Remove unnecessary dependency on sap-installation-wizard
    + Remove unnecessary dependency on ha-cluster-bootstrap
* Mon Jul 17 2017 imanyugin@suse.com
- Version bump to 1.0.0;
- Fix bsc#1045482: incorrect opetationMode for HANA 2.0;
- Adapt module for changes in HANA 2.0;
- Store and recover settings for unfinished cluster configurations;
* Thu Mar 16 2017 imanyugin@suse.com
- Version bump to 0.9.7;
- Fix bsc#1029694: the wizard cannot detect available watchdog modules;
- Improved log in ncruses mode;
- Change layout of the overview screen;
* Wed Oct  5 2016 imanyugin@suse.com
- Version bump to 0.9.6;
- Fix HANA configuration page issue (bsc#1003078);
* Fri Sep 30 2016 imanyugin@suse.com
- Version bump to 0.9.5;
- Fix the issue with parsing HANA .ini files (bsc#999291);
* Wed Sep 28 2016 imanyugin@suse.com
- Version bump to 0.9.4;
- Fix cluster configuration (excessive semicolon in corosync.conf), fix bsc#1001442;
- Fix Hook script parameters in HANA Performance-Optimized scenario, fix bsc#1001445;
* Fri Sep 16 2016 imanyugin@suse.com
- Update version to 0.9.3;
- Add Cost-Optimized scenario for SAP HANA (bsc#999276);
- New dependencies:
  * ruby2.1-rubygem-cfa for configuration files parsing
  * sysvinit-tools for `pidof` binary
* Wed Aug 31 2016 imanyugin@suse.com
- Update to version 0.9.1;
- Fix appending /etc/hosts (bsc#995765);
* Wed Aug 24 2016 imanyugin@suse.com
- Update to version 0.9.0;
- Change SBD device addressing to udev-generated paths;
- Allow users to use arbitrary netmasks for corosync rings (bsc#992393);
- Put the cluster into maintenance mode prior to configuration (bsc#992358);
- Show scenario prerequisites on the first screen (bsc#992379);
- HANA Configuration: Add the replicationMode parameter;
- Allow user to create an initial HANA backup, provided the secure store key is present;
* Fri Jul  8 2016 imanyugin@suse.com
- Fix the bug when reading NTP configuration crashed the module; a workaround for bsc#987064
* Wed Jun 29 2016 imanyugin@suse.com
- Update to version 0.8.0;
- Added HANA Scale Up: Performance-optimized scenario;
- Added a new Yast client sap_ha_rpc for the RPC server;
- Enhanced the HANA configuration (backup settings, site names settings);
- Split the Cluster wizard page into two;
- Cluster configuration can generate and read corosync and csync2 auth keys;
- Cluster ring address selection considers network addresses of the local node;
- fate#319068;
* Tue Jun 14 2016 imanyugin@suse.com
- Update to version 0.6.6;
- Fixed a bug in Cluster Configuration page;
- fate#319068;
* Mon Jun 13 2016 imanyugin@suse.com
- Added XML RPC functionality to manipulate remote nodes;
- GUI changes: merged Communication Layer and Cluster Nodes pages of the wizard together, minor changes;
- HANA cluster bootstrapping works, as part of fate#319068;
* Fri May 27 2016 ilya.manyugin@suse.com
- Initial release, version 0.6.0. fate#319068
